
public class Automat {
  Vare[] varer; // varene som kan kjpes fra automaten
  double pris; // felles pris for alle varer
  double mottattBelp; // penger brukeren har lagt p automaten
  double vekslePenger; // penger automaten kan gi igjen som veksel
  double kasse; // penger som ikke kan gis tilbake som veksel
  private Display display; // display-vindu der informasjon kan vises

  Automat(Vare[] varer, double pris, double veksel) {
    this.varer = varer;
    this.pris = pris;
    vekslePenger = veksel;
    mottattBelp = 0.0;
    kasse = 0.0;
    display = new Display();
  }

  private void giMelding(String melding) {
    display.visMelding(melding);
  }

  public double finnPris(int vareValg) { // NB. Parameteren er overfldig.
    return pris;
  }

  public void mottaPenger(double belp) {
    mottattBelp += belp;
    giMelding("Mottatt: " + mottattBelp + " kr");
  }

  private boolean vareFinnes(int vareValg) {
    assert vareValg >= 0 && vareValg < varer.length : "Varenummer m vre mellom 0 og "
        + (varer.length - 1);
    return (varer[vareValg].hentBeholdning() > 0);
  }

  private void leverVare(int vareValg) {
    // her vil automaten plassere valgt vare i mottakerluken
    giMelding("Varen " + varer[vareValg].hentVarenavn() + " ligger i luken");
  }

  private void giVekslePenger(double veksel) {
    // her vil automaten gi tilbake vekslepenger i returluken
    giMelding("Vekslepenger " + veksel + " ligger i pengeluken");
    vekslePenger -= veksel;
  }

  private void oppdaterKassen(double belp) {
    kasse += belp;
  }

  public void velgVare(int vareValg) {
    if (vareValg < 0 || vareValg >= varer.length) {
      giMelding("Feil vareslag angivelse: " + vareValg);
      giMelding("Mottatt belp " + mottattBelp + " returneres.");
      mottattBelp = 0.0;
      return;
    }
    if (vareFinnes(vareValg)) {
      double pris = finnPris(vareValg);
      if (mottattBelp >= pris) {
        leverVare(vareValg);
        varer[vareValg].settBeholdning(varer[vareValg].hentBeholdning() - 1);
        giVekslePenger(mottattBelp - pris);
        oppdaterKassen(mottattBelp);
        mottattBelp = 0.0;
        giMelding("Takk for handelen og velkommen tilbake!");
      } else { // mottatt belp mindre enn pris
        giMelding("For lite penger innkast. " + varer[vareValg].hentVarenavn()
            + " koster " + pris + " kr");
      }
    } else { // tom for denne varen
      giMelding("Dessverre tom for " + varer[vareValg].hentVarenavn());
    }
  }

  public void avbryt() {
    giVekslePenger(mottattBelp);
    giMelding("Vareutlevering er avbrutt.");
    mottattBelp = 0.0;
  }

  public void visUtvalg() {
    String str = "Automaten inneholder varene:";
    str += this;
    str += "\nHver vare koster: " + pris;
    str += "\nVekslepenger: " + vekslePenger;
    str += "\nKasse: " + kasse;
    str += "\nInnkast: " + mottattBelp;
    System.out.println(str);
  }
  @Override
  public String toString() { // overkjrer toString() fra Object-klassen
    String str = "";
    for (int i = 0; i < varer.length; i++) {
      str += "\nVarenummer: " + i;
      str += varer[i];
    }
    return str;
  }
}